==> sal-course-2.3.0-20160924.074255-26-sources.jar: com/baijia/tianxiao/sal/course/dto/OrgRecommendCourseListDto.java <==

 /**
 * Baijiahulian.com Inc.
 * Copyright (c) 2014-2015 All Rights Reserved.
 */
    
package com.baijia.tianxiao.sal.course.dto;

import com.baijia.tianxiao.dto.BaseDto;

/**
 * @title OrgRecommendCourseListDto
 * @desc TODO 
 * @author zhangbing
 * @date 2015年12月28日
 * @version 1.0
 */
public class OrgRecommendCourseListDto extends BaseDto {

    private static final long serialVersionUID = -904310788382068641L;
    
    //课程名称
    private String name;
    
    //课程详情页
    private String link;
    
    //课程封面
    private String preface;
    
    //课程价格
    private String price;
    
    //课程类型,0-未知,2-班课,4-微课
    private Integer courseType;
    
    //课程number
    private Long number;
    
    //课程ID
    private Long courseId;

    /**
     * @return the name
     */
    
    public String getName() {
    
        return name;
    }

    /**
     * @param name the name to set
     */
    
    public void setName(String name) {
    
        this.name = name;
    }

    /**
     * @return the link
     */
    
    public String getLink() {
    
        return link;
    }

    /**
     * @param link the link to set
     */
    
    public void setLink(String link) {
    
        this.link = link;
    }

    /**
     * @return the preface
     */
    
    public String getPreface() {
    
        return preface;
    }

    /**
     * @param preface the preface to set
     */
    
    public void setPreface(String preface) {
    
        this.preface = preface;
    }

    /**
     * @return the price
     */
    
    public String getPrice() {
    
        return price;
    }

    /**
     * @param price the price to set
     */
    
    public void setPrice(String price) {
    
        this.price = price;
    }

    /**
     * @return the courseType
     */
    
    public Integer getCourseType() {
    
        return courseType;
    }

    /**
     * @param courseType the courseType to set
     */
    
    public void setCourseType(Integer courseType) {
    
        this.courseType = courseType;
    }

    /**
     * @return the number
     */
    
    public Long getNumber() {
    
        return number;
    }

    /**
     * @param number the number to set
     */
    
    public void setNumber(Long number) {
    
        this.number = number;
    }

    /**
     * @return the courseId
     */
    
    public Long getCourseId() {
    
        return courseId;
    }

    /**
     * @param courseId the courseId to set
     */
    
    public void setCourseId(Long courseId) {
    
        this.courseId = courseId;
    }
}

==> sal-course-2.13.0-20170223.121137-43-sources.jar: com/baijia/tianxiao/sal/course/dto/OrgRecommendCourseListDto.java <==

 /**
 * Baijiahulian.com Inc.
 * Copyright (c) 2014-2015 All Rights Reserved.
 */
    
package com.baijia.tianxiao.sal.course.dto;

import com.baijia.tianxiao.dto.BaseDto;

/**
 * @title OrgRecommendCourseListDto
 * @desc TODO 
 * @author zhangbing
 * @date 2015年12月28日
 * @version 1.0
 */
public class OrgRecommendCourseListDto extends BaseDto {

    private static final long serialVersionUID = -904310788382068641L;
    
    //课程名称
    private String name;
    
    //课程详情页
    private String link;
    
    //课程封面
    private String preface;
    
    //课程价格
    private String price;
    
    //课程类型,0-未知,2-班课,4-微课,8-1V1课程
    private Integer courseType;
    
    //课程number
    private Long number;
    
    //课程ID
    private Long courseId;

    /**
     * @return the name
     */
    
    public String getName() {
    
        return name;
    }

    /**
     * @param name the name to set
     */
    
    public void setName(String name) {
    
        this.name = name;
    }

    /**
     * @return the link
     */
    
    public String getLink() {
    
        return link;
    }

    /**
     * @param link the link to set
     */
    
    public void setLink(String link) {
    
        this.link = link;
    }

    /**
     * @return the preface
     */
    
    public String getPreface() {
    
        return preface;
    }

    /**
     * @param preface the preface to set
     */
    
    public void setPreface(String preface) {
    
        this.preface = preface;
    }

    /**
     * @return the price
     */
    
    public String getPrice() {
    
        return price;
    }

    /**
     * @param price the price to set
     */
    
    public void setPrice(String price) {
    
        this.price = price;
    }

    /**
     * @return the courseType
     */
    
    public Integer getCourseType() {
    
        return courseType;
    }

    /**
     * @param courseType the courseType to set
     */
    
    public void setCourseType(Integer courseType) {
    
        this.courseType = courseType;
    }

    /**
     * @return the number
     */
    
    public Long getNumber() {
    
        return number;
    }

    /**
     * @param number the number to set
     */
    
    public void setNumber(Long number) {
    
        this.number = number;
    }

    /**
     * @return the courseId
     */
    
    public Long getCourseId() {
    
        return courseId;
    }

    /**
     * @param courseId the courseId to set
     */
    
    public void setCourseId(Long courseId) {
    
        this.courseId = courseId;
    }
}
